/**
 * Note: The following flynt-disable is because in this message we have a special case that this message represents
 * an aggregation by automation ID but the message itself has no ID of it's own.
 */
export interface ActivationSummary {
    /**
     * Automation ID
     * @format GUID
     */
    automationId?: string | null;
    /** Preinstalled origin info */
    preinstalledOrigin?: PreinstalledOrigin;
    /** Total activations count per the automation */
    activationsCount?: number;
    /** When the automation was last activated */
    lastActivatedDate?: Date | null;
    /**
     * Migrated activations count
     * - If present, indicates the count of activations migrated from the old system
     * - If absent, indicates the migration has not been performed yet for this automation
     */
    migratedActivationsCount?: number | null;
    /** When the automation was last activated */
    migratedLastActivatedDate?: Date | null;
}
export interface PreinstalledOrigin {
    /**
     * Identifier for the application
     * @format GUID
     */
    appId?: string;
    /**
     * Application component ID
     * @format GUID
     */
    componentId?: string;
}
export interface GetActivationSummaryRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
}
export interface GetActivationSummaryResponse {
    /** Activation summary per automation */
    activationSummary?: ActivationSummary;
}
export interface GetActivationSummaryByPreinstalledOriginRequest {
    /**
     * Preinstalled automation app ID
     * @format GUID
     */
    appId: string;
    /**
     * Preinstalled automation component ID
     * @format GUID
     */
    componentId: string;
}
export interface GetActivationSummaryByPreinstalledOriginResponse {
    /** Grouped activation summary by (app_id, component_id) */
    activationSummary?: ActivationSummary;
}
export interface MigrateActivationsCountRequest {
    /**
     * MetaSite ID
     * @format GUID
     */
    metaSiteId: string;
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /** Preinstalled info */
    preinstalledOrigin?: PreinstalledOrigin;
    /** Migrated activations count for automation */
    activationsCount: number | null;
    /** When the automation was last activated */
    lastActivatedDate: Date | null;
}
export interface MigrateActivationsCountResponse {
}
interface PreinstalledOriginNonNullableFields {
    appId: string;
    componentId: string;
}
interface ActivationSummaryNonNullableFields {
    preinstalledOrigin?: PreinstalledOriginNonNullableFields;
    activationsCount: number;
}
export interface GetActivationSummaryResponseNonNullableFields {
    activationSummary?: ActivationSummaryNonNullableFields;
}
export interface GetActivationSummaryByPreinstalledOriginResponseNonNullableFields {
    activationSummary?: ActivationSummaryNonNullableFields;
}
export {};
