"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.migrateActivationsCount = exports.getActivationSummaryByPreinstalledOrigin = exports.getActivationSummary = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixAutomationsActivationLogsV1ActivationSummary = __importStar(require("./automations-activation-logs-v1-activation-summary-activation-action-summary.http.js"));
/**
 * Get activation summary by automation id
 * @param automationId - Automation ID
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.ACTIVATION_SUMMARY_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @returns Activation summary per automation
 * @fqn wix.automations.activation_logs.v1.ActivationSummariesService.GetActivationSummary
 */
async function getActivationSummary(automationId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        automationId: automationId,
    });
    const reqOpts = ambassadorWixAutomationsActivationLogsV1ActivationSummary.getActivationSummary(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)
            ?.activationSummary;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { automationId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['automationId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getActivationSummary = getActivationSummary;
/** @public
 * @documentationMaturity preview
 * @requiredField identifiers
 * @requiredField identifiers.appId
 * @requiredField identifiers.componentId
 * @permissionId AUTOMATIONS.ACTIVATION_SUMMARY_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.activation_logs.v1.ActivationSummariesService.GetActivationSummaryByPreinstalledOrigin
 */
async function getActivationSummaryByPreinstalledOrigin(identifiers) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        appId: identifiers?.appId,
        componentId: identifiers?.componentId,
    });
    const reqOpts = ambassadorWixAutomationsActivationLogsV1ActivationSummary.getActivationSummaryByPreinstalledOrigin(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                appId: '$[0].appId',
                componentId: '$[0].componentId',
            },
            singleArgumentUnchanged: false,
        }, ['identifiers']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getActivationSummaryByPreinstalledOrigin = getActivationSummaryByPreinstalledOrigin;
/**
 * migrate activations count
 * @param metaSiteId - MetaSite ID
 * @public
 * @documentationMaturity preview
 * @requiredField metaSiteId
 * @requiredField options.activationsCount
 * @requiredField options.automationId
 * @requiredField options.lastActivatedDate
 * @permissionId AUTOMATIONS.ACTIVATION_SUMMARY_WRITE
 * @fqn wix.automations.activation_logs.v1.ActivationSummariesService.MigrateActivationsCount
 */
async function migrateActivationsCount(metaSiteId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        metaSiteId: metaSiteId,
        automationId: options?.automationId,
        preinstalledOrigin: options?.preinstalledOrigin,
        activationsCount: options?.activationsCount,
        lastActivatedDate: options?.lastActivatedDate,
    });
    const reqOpts = ambassadorWixAutomationsActivationLogsV1ActivationSummary.migrateActivationsCount(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                metaSiteId: '$[0]',
                automationId: '$[1].automationId',
                preinstalledOrigin: '$[1].preinstalledOrigin',
                activationsCount: '$[1].activationsCount',
                lastActivatedDate: '$[1].lastActivatedDate',
            },
            singleArgumentUnchanged: false,
        }, ['metaSiteId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.migrateActivationsCount = migrateActivationsCount;
//# sourceMappingURL=automations-activation-logs-v1-activation-summary-activation-action-summary.universal.js.map