import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformSDKTimestampToRESTTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixAutomationsActivationLogsV1ActivationSummariesServiceUrl(opts) {
    const domainToMappings = {
        'bo._base_domain_': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'wixbo.ai': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'wix-bo.com': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/activation-logs',
                destPath: '',
            },
            {
                srcPath: '/_api/activation-logs',
                destPath: '/api',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_automations-activation-summary_activation-action-summary';
/** Get activation summary by automation id */
export function getActivationSummary(payload) {
    function __getActivationSummary({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.activation_logs.v1.activation_summary',
            method: 'GET',
            methodFqn: 'wix.automations.activation_logs.v1.ActivationSummariesService.GetActivationSummary',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsActivationLogsV1ActivationSummariesServiceUrl({
                protoPath: '/v2/activation-summaries/{automationId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'activationSummary.lastActivatedDate' },
                        { path: 'activationSummary.migratedLastActivatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getActivationSummary;
}
export function getActivationSummaryByPreinstalledOrigin(payload) {
    function __getActivationSummaryByPreinstalledOrigin({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.activation_logs.v1.activation_summary',
            method: 'GET',
            methodFqn: 'wix.automations.activation_logs.v1.ActivationSummariesService.GetActivationSummaryByPreinstalledOrigin',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsActivationLogsV1ActivationSummariesServiceUrl({
                protoPath: '/v2/activation-summaries/preinstalled/{appId}/{componentId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'activationSummary.lastActivatedDate' },
                        { path: 'activationSummary.migratedLastActivatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getActivationSummaryByPreinstalledOrigin;
}
/** migrate activations count */
export function migrateActivationsCount(payload) {
    function __migrateActivationsCount({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'lastActivatedDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.activation_logs.v1.activation_summary',
            method: 'POST',
            methodFqn: 'wix.automations.activation_logs.v1.ActivationSummariesService.MigrateActivationsCount',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsActivationLogsV1ActivationSummariesServiceUrl({
                protoPath: '/v1/migration-rules/migrate',
                data: serializedData,
                host,
            }),
            data: serializedData,
        };
        return metadata;
    }
    return __migrateActivationsCount;
}
//# sourceMappingURL=automations-activation-logs-v1-activation-summary-activation-action-summary.http.js.map