/**
 * Note: The following flynt-disable is because in this message we have a special case that this message represents
 * an aggregation by automation ID but the message itself has no ID of it's own.
 */
export interface ActivationSummary {
    /**
     * Automation ID
     * @format GUID
     */
    automationId?: string | null;
    /** Preinstalled origin info */
    preinstalledOrigin?: PreinstalledOrigin;
    /** Total activations count per the automation */
    activationsCount?: number;
    /** When the automation was last activated */
    lastActivatedDate?: Date | null;
    /**
     * Migrated activations count
     * - If present, indicates the count of activations migrated from the old system
     * - If absent, indicates the migration has not been performed yet for this automation
     */
    migratedActivationsCount?: number | null;
    /** When the automation was last activated */
    migratedLastActivatedDate?: Date | null;
}
export interface PreinstalledOrigin {
    /**
     * Identifier for the application
     * @format GUID
     */
    appId?: string;
    /**
     * Application component ID
     * @format GUID
     */
    componentId?: string;
}
export interface GetActivationSummaryRequest {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
}
export interface GetActivationSummaryResponse {
    /** Activation summary per automation */
    activationSummary?: ActivationSummary;
}
export interface GetActivationSummaryByPreinstalledOriginRequest {
    /**
     * Preinstalled automation app ID
     * @format GUID
     */
    appId: string;
    /**
     * Preinstalled automation component ID
     * @format GUID
     */
    componentId: string;
}
export interface GetActivationSummaryByPreinstalledOriginResponse {
    /** Grouped activation summary by (app_id, component_id) */
    activationSummary?: ActivationSummary;
}
export interface MigrateActivationsCountRequest {
    /**
     * MetaSite ID
     * @format GUID
     */
    metaSiteId: string;
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /** Preinstalled info */
    preinstalledOrigin?: PreinstalledOrigin;
    /** Migrated activations count for automation */
    activationsCount: number | null;
    /** When the automation was last activated */
    lastActivatedDate: Date | null;
}
export interface MigrateActivationsCountResponse {
}
interface PreinstalledOriginNonNullableFields {
    appId: string;
    componentId: string;
}
export interface ActivationSummaryNonNullableFields {
    preinstalledOrigin?: PreinstalledOriginNonNullableFields;
    activationsCount: number;
}
export interface GetActivationSummaryResponseNonNullableFields {
    activationSummary?: ActivationSummaryNonNullableFields;
}
export interface GetActivationSummaryByPreinstalledOriginResponseNonNullableFields {
    activationSummary?: ActivationSummaryNonNullableFields;
}
/**
 * Get activation summary by automation id
 * @param automationId - Automation ID
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.ACTIVATION_SUMMARY_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @returns Activation summary per automation
 * @fqn wix.automations.activation_logs.v1.ActivationSummariesService.GetActivationSummary
 */
export declare function getActivationSummary(automationId: string): Promise<ActivationSummary & ActivationSummaryNonNullableFields>;
/** @public
 * @documentationMaturity preview
 * @requiredField identifiers
 * @requiredField identifiers.appId
 * @requiredField identifiers.componentId
 * @permissionId AUTOMATIONS.ACTIVATION_SUMMARY_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.activation_logs.v1.ActivationSummariesService.GetActivationSummaryByPreinstalledOrigin
 */
export declare function getActivationSummaryByPreinstalledOrigin(identifiers: GetActivationSummaryByPreinstalledOriginIdentifiers): Promise<GetActivationSummaryByPreinstalledOriginResponse & GetActivationSummaryByPreinstalledOriginResponseNonNullableFields>;
export interface GetActivationSummaryByPreinstalledOriginIdentifiers {
    /**
     * Preinstalled automation app ID
     * @format GUID
     */
    appId: string;
    /**
     * Preinstalled automation component ID
     * @format GUID
     */
    componentId: string;
}
/**
 * migrate activations count
 * @param metaSiteId - MetaSite ID
 * @public
 * @documentationMaturity preview
 * @requiredField metaSiteId
 * @requiredField options.activationsCount
 * @requiredField options.automationId
 * @requiredField options.lastActivatedDate
 * @permissionId AUTOMATIONS.ACTIVATION_SUMMARY_WRITE
 * @fqn wix.automations.activation_logs.v1.ActivationSummariesService.MigrateActivationsCount
 */
export declare function migrateActivationsCount(metaSiteId: string, options?: MigrateActivationsCountOptions): Promise<void>;
export interface MigrateActivationsCountOptions {
    /**
     * Automation ID
     * @format GUID
     */
    automationId: string;
    /** Preinstalled info */
    preinstalledOrigin?: PreinstalledOrigin;
    /** Migrated activations count for automation */
    activationsCount: number | null;
    /** When the automation was last activated */
    lastActivatedDate: Date | null;
}
export {};
